--- v477/include/asm-arm/arch-sa1100/time.h	Thu Jun 12 09:57:59 2003
+++ seeburg-v477/include/asm-arm/arch-sa1100/time.h	Fri Aug 10 19:29:55 2007
@@ -4,7 +4,7 @@
  * Copyright (C) 1998 Deborah Wallach.
  * Twiddles  (C) 1999 Hugo Fiennes <hugo@empeg.com>
  * Fixed lockups 2002 Mark Lord <mlord@pobox.com>
- *
+ * Copyright (C) 2007 Scott Swazey <scott451@gmail.com> // Added Seeburg code
  */
 
 #include <asm/arch/hardware.h>
@@ -13,6 +13,7 @@
 static volatile unsigned long next_os_timer_match = 0;
 static volatile unsigned long last_os_timer_match = 0;
 
+
 /* IRQs are disabled before entering here from do_gettimeofday() */
 extern __inline__ unsigned long gettimeoffset (void)
 {
@@ -51,6 +52,58 @@
 	   hugo@empeg.com
         */
         save_flags_clif(flags);       // was save_flags_cli()  --M.Lord
+ 
+#define MAX_SAMPLES 256		// --S.Swazey
+#ifdef MAX_SAMPLES
+  {
+/* Seeburg pulse sampler */
+    extern unsigned long pulse_samples[MAX_SAMPLES];
+    extern volatile long samples_collected;
+    extern volatile int sampler_state;
+    extern struct semaphore seeburg_sem;
+
+/* sample CTS for Seeburg wallbox.  log 31 bits of system tick count and CTS state as LSB */
+    if (sampler_state)
+      {
+	switch (sampler_state)
+	  {
+	  case 1:		// watch for falling edge
+	    if (!(GPLR & EMPEG_SERIALCTS))
+	      break;		// nothing
+	    samples_collected = 0;
+	    sampler_state = 2;
+	    // fall through
+	  case 2:
+	    if (samples_collected < MAX_SAMPLES)
+	      {
+		if (GPLR & EMPEG_SERIALCTS)
+		  pulse_samples[samples_collected] = OSCR | 0x00000001;	// force LSB on
+		else
+		  pulse_samples[samples_collected] = OSCR & 0xfffffffe;	// force LSB off
+		samples_collected++;
+	      }
+	    else
+	      {
+		sampler_state = 3;	// got 256 samples
+		up (&seeburg_sem);	// mark data as ready for driver
+	      }
+	    break;
+
+	  case 3:		// wait for device driver to pickup samples
+	    break;
+
+	  case 4:		// driver picked up sample, so we clear the buffer and re-arm
+	    samples_collected = 0;
+	    sampler_state = 1;
+	    break;
+
+	  default:
+	    sampler_state = 0;
+	  }
+      }
+  }
+#endif // -- S.Swazey
+
 	last_os_timer_match=OSMR0;
 
         /* Clear match on timer 0 */
